@@ -28,7 +28,7 @@ def validate_match_columns(import_log, model_class, header_row):
     field_names = model_class._meta.get_all_field_names()
     for field_name in field_names:
         field_object, model, direct, m2m = model_class._meta.get_field_by_name(field_name)
-        if direct and model and not field_object.blank:
+        if direct and model and not field_object.blank and import_log.import_type != "O": # Skip if Update Only
             field_matches = column_matches.filter(field_name=field_name)
             match_in_header = False
             if field_matches:
@@ -106,7 +106,7 @@ def match_columns(request, import_log_id):
                     match_relations,
                     kwargs={'import_log_id': import_log.id}))
     else:
-        existing_matches = import_log.get_matches()
+        existing_matches = import_log.get_matches()        
         formset = MatchFormSet(queryset=existing_matches)
         
     field_choices = (('', 'Do Not Use'),)
@@ -133,8 +133,9 @@ def match_columns(request, import_log_id):
     
     # Include django-custom-field support
     custom_fields = get_custom_fields_from_model(model_class)
-    for custom_field in custom_fields:
-        field_choices += (("simple_import_custom__{0}".format(custom_field),
+    if custom_fields:
+        for custom_field in custom_fields:
+            field_choices += (("simple_import_custom__{0}".format(custom_field),
                            "{0} (Custom)".format(custom_field)),)
     # Include defined methods
     # Model must have a simple_import_methods defined
@@ -182,7 +183,7 @@ def match_relations(request, import_log_id):
                     import_log=import_log,
                     field_name=match.field_name)
                 field_names += [match.field_name]
-                choices = (('', '---------'),)
+                choices = ()
                 for field in get_direct_fields_from_model(field.related.parent_model()):
                     if field.unique:
                         choices += ((field.name, field.verbose_name),)
@@ -347,6 +348,13 @@ def do_import(request, import_log_id):
                 exc = sys.exc_info()
                 error_data += [row + ["No Record Found to Update", unicode(exc[1])]]
                 fail_count += 1
+            except ValueError:
+                exc = sys.exc_info()
+                if str(exc[1]).startswith('invalid literal for int() with base 10'):
+                    error_data += [row + ["Incompatible Data - A number was expected, but a character was used", unicode(exc[1])]] 
+                else:
+                    error_data += [row + ["Value Error", unicode(exc[1])]]
+                fail_count += 1
             except:
                 exc = sys.exc_info()
                 error_data += [row + ["Unknown Error", unicode(exc[1])]]
